/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2014 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.admin.reseller.rmi.impl;

import java.io.UnsupportedEncodingException;
import java.security.NoSuchAlgorithmException;
import com.openexchange.admin.plugins.BasicAuthenticatorPluginInterface;
import com.openexchange.admin.reseller.rmi.dataobjects.ResellerAdmin;
import com.openexchange.admin.reseller.storage.interfaces.OXResellerStorageInterface;
import com.openexchange.admin.rmi.dataobjects.Credentials;
import com.openexchange.admin.rmi.exceptions.InvalidCredentialsException;
import com.openexchange.admin.rmi.exceptions.InvalidDataException;
import com.openexchange.admin.rmi.exceptions.StorageException;
import com.openexchange.admin.rmi.impl.OXCommonImpl;
import com.openexchange.admin.tools.GenericChecks;

/**
 * @author choeger
 *
 */
public class ResellerAuth extends OXCommonImpl implements BasicAuthenticatorPluginInterface {

    private static final org.slf4j.Logger log = org.slf4j.LoggerFactory.getLogger(ResellerAuth.class);

    public ResellerAuth() throws StorageException {
        super();
    }


    /* (non-Javadoc)
     * @see com.openexchange.admin.plugins.OXBasicAuthenticatorPluginInterface#doAuthentication(com.openexchange.admin.rmi.dataobjects.Credentials)
     */
    @Override
    public void doAuthentication(Credentials authdata) throws InvalidCredentialsException {
        try {
            doNullCheck(authdata);
        } catch (InvalidDataException e) {
            log.error("authdata is null", e);
            throw new InvalidCredentialsException("authentication failed");
        }
        try {
            OXResellerStorageInterface oxresell = OXResellerStorageInterface.getInstance();
            ResellerAdmin adm = oxresell.getData(new ResellerAdmin[]{new ResellerAdmin(authdata.getLogin())})[0];
            if( ! GenericChecks.authByMech(adm.getPassword(), authdata.getPassword(), adm.getPasswordMech()) ) {
                throw new InvalidCredentialsException("authentication failed");
            }
        } catch (StorageException e) {
            log.error("",e);
            throw new InvalidCredentialsException("authentication failed");
        } catch (InvalidCredentialsException e) {
            log.error("",e);
            throw e;
        } catch (NoSuchAlgorithmException e) {
            log.error("",e);
            throw new InvalidCredentialsException("authentication failed");
        } catch (UnsupportedEncodingException e) {
            log.error("",e);
            throw new InvalidCredentialsException("authentication failed");
        }
    }

}
